from prompt_toolkit import print_formatted_text, HTML


def print_error(msg, start="", end=""):
    print_formatted_text(HTML(f"<red>{start}[!] </red> {msg}{end}"))

def print_ok(msg, start="", end=""):
    print_formatted_text(HTML(f"<green>{start}[+] </green>{msg}{end}"))


from emailfinder import __version__
from random import choice
from prompt_toolkit.formatted_text import FormattedText
from prompt_toolkit import print_formatted_text
from pyfiglet import Figlet


author = "@JosueEncinar"
description = "Search emails from a domain through search engines."
usage_example = "emailfinder -d domain.com"


def show_banner():
    fonts = ["graffiti", "smshadow", "standard", "cosmic", "speed", "epic"]
    custom_banner = Figlet(font=choice(fonts))
    banner = custom_banner.renderText("eFnDR")
    print_formatted_text(f"{banner}")
    print(f"|_ Author: {author}")
    print(f"|_ Description: {description}")
    print(f"|_ Version: {__version__}")
    print(f"|_ Usage: {usage_example}")
    print("")



import argparse
from emailfinder.utils.banner import show_banner
from emailfinder.core import processing
from emailfinder import __version__


def main(argv=None):
    """The entry point for the script

   Args:
       argv (list): The list of parameters passed.
    """
    parser = argparse.ArgumentParser()
    parser.add_argument('-d','--domain', help="Domain to search",required=True)
    parser.add_argument('-v','--version', help="Show Emailfinder version", action='version', version=__version__)

    args = parser.parse_args()
    show_banner()

    # limit = 200

    try:
        processing(args.domain)
    except KeyboardInterrupt:
        print("[-] EmailFinder has been interrupted. ")


if __name__ == '__main__':
    main(sys.argv[1:])

